Struct Login
pub struct Login {
pub admin_pwd: Option<String>,
}Expand description
Serialized arguments for the login server function.
Fields
admin_pwd: Option<String>Methods from Deref<Target = Option<String>>
1.0.0 ยท Sourcepub fn as_ref(&self) -> Option<&T>
pub fn as_ref(&self) -> Option<&T>
Converts from &Option<T> to Option<&T>.
Examples
Calculates the length of an Option<String> as an Option<usize>
without moving the String. The map method takes the self argument by value,
consuming the original, so this technique uses as_ref to first take an Option to a
reference to the value inside the original.
let text: Option<String> = Some("Hello, world!".to_string());
// First, cast `Option<String>` to `Option<&String>` with `as_ref`,
// then consume *that* with `map`, leaving `text` on the stack.
let text_length: Option<usize> = text.as_ref().map(|s| s.len());
println!("still can print text: {text:?}");1.75.0 ยท Sourcepub fn as_slice(&self) -> &[T]
pub fn as_slice(&self) -> &[T]
Returns a slice of the contained value, if any. If this is None, an
empty slice is returned. This can be useful to have a single type of
iterator over an Option or slice.
Note: Should you have an Option<&T> and wish to get a slice of T,
you can unpack it via opt.map_or(&[], std::slice::from_ref).
Examples
assert_eq!(
[Some(1234).as_slice(), None.as_slice()],
[&[1234][..], &[][..]],
);The inverse of this function is (discounting
borrowing) [_]::first:
for i in [Some(1234_u16), None] {
assert_eq!(i.as_ref(), i.as_slice().first());
}1.40.0 ยท Sourcepub fn as_deref(&self) -> Option<&<T as Deref>::Target>where
T: Deref,
pub fn as_deref(&self) -> Option<&<T as Deref>::Target>where
T: Deref,
Converts from Option<T> (or &Option<T>) to Option<&T::Target>.
Leaves the original Option in-place, creating a new one with a reference
to the original one, additionally coercing the contents via Deref.
Examples
let x: Option<String> = Some("hey".to_owned());
assert_eq!(x.as_deref(), Some("hey"));
let x: Option<String> = None;
assert_eq!(x.as_deref(), None);Trait Implementations
impl<'de> Deserialize<'de> for Login
impl<'de> Deserialize<'de> for Login
fn deserialize<__D>(
__deserializer: __D,
) -> Result<Login, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<Login, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
impl Serialize for Login
impl Serialize for Login
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
impl ServerFn for Login
impl ServerFn for Login
const PATH: &'static str
const PATH: &'static str
type Client = BrowserClient
type Client = BrowserClient
type Server = AxumServerFnBackend
type Server = AxumServerFnBackend
type Protocol = Http<PostUrl, Post<JsonEncoding>>
type Protocol = Http<PostUrl, Post<JsonEncoding>>
type Output = Option<LoginState>
type Output = Option<LoginState>
type Error = ServerFnError<LoginError>
type Error = ServerFnError<LoginError>
ServerFnError], but allowed to be any type that implements [FromServerFnError].type InputStreamError = ServerFnError<LoginError>
type InputStreamError = ServerFnError<LoginError>
ServerFnError], but allowed to be any type that implements [FromServerFnError].type OutputStreamError = ServerFnError<LoginError>
type OutputStreamError = ServerFnError<LoginError>
ServerFnError], but allowed to be any type that implements [FromServerFnError].fn middlewares() -> Vec<Arc<dyn Layer<<<Login as ServerFn>::Server as Server<<Login as ServerFn>::Error>>::Request, <<Login as ServerFn>::Server as Server<<Login as ServerFn>::Error>>::Response>>>
fn middlewares() -> Vec<Arc<dyn Layer<<<Login as ServerFn>::Server as Server<<Login as ServerFn>::Error>>::Request, <<Login as ServerFn>::Server as Server<<Login as ServerFn>::Error>>::Response>>>